##  Report Content
The report exports as an XLSX spreadsheet containing user PII changes. It does not include audit logs for other areas of the LeanIX product.
Column | Description
---|---
Author | The administrator who made the change
Change Time | Date and time when the change was made
Column | The PII field that was modified
Old Value | The previous value before the change
New Value | The updated value after the change


